@@ -29,4 +29,8 @@ public interface RealmResource {
 
     @Path("roles")
     RolesResource roles();
+
+    @Path("clients")
+    ClientsResource clients();
+
 }
